#!/bin/sh
################################################################################
#  Name:    hourly
#  Purpose: Script to 'cron' hourly to run for monitoring
#  Author:  Ronald Bradford 
#  History:  
#
#   29-MAY-2007  0.03  Introduced mysql.conf for later parameterisations
#   27-MAY-2007  0.02  Introduced standard logging/monitoring (common.sh)
#   25-MAY-2007  0.01  First revised raw version
################################################################################


SCRIPT_NAME="$0"
SCRIPT_VERSION="0.03 29-MAY-2007"
#------------------------------------------------------------------------------- 
# Initial Variables
#
DATETIME_FORMAT="+%y%m%d.%H%M%S"
DATETIME=`date $DATETIME_FORMAT`
[ -z "$LOG_DIR" ] && LOG_DIR="/tmp"

. ./common.sh
. ./mysql.conf



#---------------------------------------------------------------------  usage -- 
usage() {
  echo ""
  echo "	Usage:  $SCRIPT_NAME [-d database] [-v sec]"
  echo "          -d  database for table status"
  echo "          -v  seconds for 'vmstat'"
  echo "          -h  help"
  echo ""
  echo "          Version:  $SCRIPT_VERSION"
  leave 1
}

#--------------------------------------------------------------- process_args -- 
process_args() {

  set -- `getopt "hdv" "$@"`

  while :
  do
          case "$1" in
          -h) usage; leave 0;;
          -d) DATABASE="$2"; shift;;
          -v) VM_INTERVAL="$2"; shift;;
          --) break;;
          esac
          shift
  done
  shift 
  log $INFO "Checking Arguments"
  [ -z $"DATABASE" ] && DATABASE=$MYSQL_DATABASE
}


#----------------------------------------------------------------- configure -- 
configure() {

  log $INFO "Checking configuration"
  [ -z $MYSQL_AUTHENTICATION ] && 
     error "You must specify a MySQL Authentication with MYSQL_AUTHENTICATION"
  [ -z `which mysqladmin` ] && error "mysqladmin must be in the PATH"
  AUTHENTICATION="$MYSQL_AUTHENTICATION"
  [ -z `$DATABASE` ] && warn "No MySQL database specified, database specific tasks will be ignored"
}

#---------------------------------------------------------------- MySQLStatus -- 
MySQLStatus() {

  COUNT=0
  MAX_COUNT=60
  SLEEP_TIME=60
  LOG_FILE1="${LOG_DIR}/mysql.status.$DATETIME.log"
  LOG_FILE2="${LOG_DIR}/mysql.processlist.$DATETIME.log"
  LOG_FILE3="${LOG_DIR}/mysql.innodbstatus.$DATETIME.log"
  > $LOG_FILE1
  > $LOG_FILE2
  > $LOG_FILE3
  info "Logging mysqladmin extended-status per $SLEEP_TIME secs for $MAX_COUNT times to $LOG_FILE1"
  info "Logging mysqladmin processlist per $SLEEP_TIME secs for $MAX_COUNT times to $LOG_FILE2"
  info "Logging mysql show innodb status per $SLEEP_TIME secs for $MAX_COUNT times to $LOG_FILE3"
  while [ $COUNT -lt $MAX_COUNT ]
  do
    NOW=`date $DATETIME_FORMAT`
    echo "| date_time                        | $NOW |" >> $LOG_FILE1
    echo $NOW >> $LOG_FILE2
    echo $NOW >> $LOG_FILE3
    mysqladmin $AUTHENTICATION extended-status >> $LOG_FILE1
    mysqladmin --verbose $AUTHENTICATION processlist >> $LOG_FILE2
    mysql $AUTHENTICATION $DATABASE -e "SHOW INNODB STATUS\G" >> $LOG_FILE3 2>&1 &
    COUNT=`expr $COUNT + 1`
    sleep $SLEEP_TIME
  done
  
}
  
#----------------------------------------------------------- MySQLTableStatus -- 
MySQLTableStatus() {
  if [ ! -z "$DATABASE" ]
  then
    LOG_FILE="${LOG_DIR}/mysql.tablestatus.$DATETIME.log"
    mysql $AUTHENTICATION $DATABASE -e "SHOW TABLE STATUS" > $LOG_FILE 2>&1 &
    #LOG_FILE="mysql.tablestatus.vertical.$DATETIME.log"
    #mysql $AUTHENTICATION $DATABASE -e "SHOW TABLE STATUS\G" > $LOG_FILE 2>&1 &
  fi
}

#------------------------------------------------------------- MySQLVariables -- 
MySQLVariables() {
  LOG_FILE="${LOG_DIR}/mysql.variables.$DATETIME.log"
  info "Logging mysqladmin variables to $LOG_FILE"
  echo "| date_time                        | $DATETIME |" > $LOG_FILE
  mysqladmin $AUTHENTICATION variables >> $LOG_FILE 2>&1 &
}

#------------------------------------------------------------------- OSvmstat -- 
OSvmstat() {
  [ -z "$VM_INTERVAL" ] && VM_INTERVAL=5
  VM_ITERATION=`expr 3600 / $VM_INTERVAL`
  VMSTAT_OPTIONS="$VM_INTERVAL $VM_ITERATION"
  LOG_FILE="${LOG_DIR}/os.vmstat.$VM_INTERVAL.$DATETIME.log"
  info "Logging vmstat $VMSTAT_OPTIONS to $LOG_FILE"
  vmstat $VMSTAT_OPTIONS > $LOG_FILE 2>&1 &
}
 
#----------------------------------------------------------------------- OSps -- 
OSps() {
  LOG_FILE="${LOG_DIR}/os.ps.$DATETIME.log"
  info "Logging ps to $LOG_FILE"
  ps -ef > $LOG_FILE 2>&1 &
}

#----------------------------------------------------------------------- MAIL -- 

#@[ $# -eq 0 ] && usage
process_args $*
configure

OSvmstat
OSps
MySQLTableStatus
MySQLVariables
MySQLStatus

info "Processing Completed"
leave 0
